KeyEvent class Events

Represents a keyboard event.

Includes the key code and optional character value.

Inheritance

Constructors

KeyEvent({required KeyCode code, String? char})
Creates a keyboard event with the given key code and optional character.
const

Properties

char → String?
The character associated with the key, if applicable.
final
code → KeyCode
The code identifying the key pressed.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited