SequenceEvent class Events

Represents a terminal escape sequence event.

Used for control sequences that are not simple key presses.

Inheritance

Constructors

SequenceEvent({required List<int> sequence, SequenceOrigin origin = SequenceOrigin.generic})
Creates an escape sequence event with the given bytes and origin.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
origin → SequenceOrigin
The origin of the escape sequence.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → List<int>
The raw sequence bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited